% Q:\trunk\reiner\ShannonKriging\TestResamplingMethods\PlotMDPI_Mar30\MatPlot_Fig8_NoiseResponse.m 
% (c) Reiner Jedermann Univesity Bremen. http://intelligentcontainer.com
% This code might be freely used, if the main article is cited:
% Jedermann, R.: Feasibility of Low Latency, Single-Sample Delay Resampling: A New Kriging Based Method. In: Algorithms 16, no. 4: 203. (doi:  10.3390/a16040203)

clear
figNum = 82;  % 81 = Fig 8a, 82 = Fig 8b


fileName = 'SimResults_Mar30.json'; 

RMSE_ALL = 0;
RMSE_EDGE = 0;
RMSE_CENTER = 1;
COMPARE_MODE  = 0;

colorMatrix = colororder;
cUni  = colorMatrix(5,:);
cJit1 = colorMatrix(1,:);
cJit2r = colorMatrix(2,:);
cMis1y = colorMatrix(3,:);
cMis2 = colorMatrix(4,:);
cHelp = colorMatrix(6,:);

fid = fopen(fileName); % Opening the file
raw = fread(fid,inf); % Reading the contents
str = char(raw'); % Transformation
fclose(fid); % Closing the file
data = jsondecode(str); % Using the jsondecode function to parse JSON from string

figure(figNum+000)
set(gca,'LineWidth',0.7);
subplot('Position',[0.13 0.13 0.85 0.85])
fontSize = 14;
colorMatrix = colororder;

testShort = sprintf('T%i', figNum);
oneTest = data.(testShort);
HW_List = oneTest.HW_List;

methods = oneTest.Methods;
m_short = fieldnames(methods);
n_methods = length(m_short);

plotName = sprintf('T%i: %s', figNum, oneTest.Name);
plotName = strrep(plotName, '_', '\_');

plotName = [plotName ' : ' oneTest.Name];

PlotList = 1:n_methods;
plotTitle = plotName;
figNumTxt = '?';

shift_Y = 10;

% default values
colorSet = {cJit2r, cUni, cJit1, cMis1y, cMis2, cHelp };
lineWidths = [1 1 1 1 1 1 1 ];
markerList = '-d-d-d-d-d';          
        
osr_cell = cell(n_methods, 1);
f40_cell = cell(n_methods, 1);

method_cell = cell(n_methods, 1);
for i = 1:n_methods
    key = m_short{i};
    m_name = methods.(key);
    method_cell{i} = m_name; 
end
legend0 = method_cell;

methodSet4 =  [
    {'Kriging'}
    {'Margolis'}
    {'Lagrange'}
    {'Akima'}         
            ];
            
switch(figNum)

    case {81}  
        plotTitle = '(a) Group delay';
        RMSE_EDGE = 0;
        markerList = '------';
        legend0 = methodSet4;

        
    case {82}  
        plotTitle = '(b) Single delay';
        RMSE_EDGE = 0;
        markerList = '----d';
        legend0 = methodSet4;
        legend0{5} = 'Kriging n{\fontsize{8}g}= 10^-^6';
        colorSet{5} = colorSet{1};
             
       

end

theLegend = cell(length(legend0),1);
if iscell(plotTitle)
    fprintf('%s --> %s \n', plotName, plotTitle{1});
else
    fprintf('%s --> %s \n', plotName, plotTitle);
end

count = 0;
count_leg = 1;
oneLegend = legend0{1};


for i=PlotList
    count = count +1;
    key = m_short{i};
    
    lw = lineWidths(count_leg);
    color = colorSet{count_leg};   
    marker1 = markerList(count);
    if marker1 == 'd'
        marker1 = '--';
    end

    
    
    if RMSE_CENTER == 1
        rmse_AC = oneTest.RmseCenter.(key);
    end
    
    if RMSE_EDGE == 1
        rmse_E = oneTest.RmseEdges.(key);
    end

    
    if RMSE_CENTER == 1    
        if i == 4
            hLine = plot(HW_List(1), db(rmse_AC(1)), 'd', 'Color', color, 'LineWidth', lw);
        else
            hLine = plot(HW_List, db(rmse_AC), marker1, 'Color', color, 'LineWidth', lw);
        end
        hold on
        if COMPARE_MODE == 1
            if mod(count,2)==0 
                % fprintf('ignore Legend %i \n', count)
                set(get(get(hLine,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
                theLegend{count_leg} = oneLegend;
                count_leg = count_leg + 1;
                if count_leg <= length(legend0)
                    oneLegend = legend0{count_leg};
                end
            end
        else
            theLegend{count_leg} = oneLegend;
            count_leg = count_leg + 1;
            if count_leg <= length(legend0)
                oneLegend = legend0{count_leg};
            end
        end
        fprintf('%s --> %s \n', key, oneLegend);
        
        
    end
    
    if RMSE_EDGE == 1
        hLine = plot(HW_List, db(rmse_E), ':', 'Color', color, 'LineWidth', lw);  %%%%%%%%%%%%%% --
        set(get(get(hLine,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
    end


end
%theLegend{count+1} = 'RMSE = 0.01';

plot([0 max(HW_List)], [0 0], 'k:')


%xlabel('Signal bandlimit / frequency f_L [Hz]', 'FontSize', fontSize);
xlabel('Window half width', 'FontSize', fontSize);
ylabel('Noise amplification [dB]', 'FontSize', fontSize);
lgd = legend(theLegend, 'FontSize', fontSize-1, 'Location','SouthEast');  % NorthWest
%lgd.FontName = 'Courier';

switch(figNum)
    case {81}  
        ylim([-2, 10]);
        xlim([2 32]); % 0.03
        text(4, 9, plotTitle, 'FontSize', fontSize)
        
    case {82}  
        ylim([-2, 30]);
        xlim([2 22]); % 0.03
        text(3, 27, plotTitle, 'FontSize', fontSize)
end
set(gca, 'FontSize', fontSize-2)
hold off

if iscell(plotTitle)
    plotTitle = plotTitle{1};
end

fprintf('\n---  T%02i --- %s --- --- f40 = \n', figNum, plotTitle)



function val = db(x)
    val = 20*log10(x);
end

